==> haskell-crypto-cipher-types-0.0.9-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-4BaVA7C69Yr3PFsK4f4Qy0
key: crypto-cipher-types-0.0.9-4BaVA7C69Yr3PFsK4f4Qy0
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: 731459fd83ec50ef72fc1b9ea7d4452b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-4BaVA7C69Yr3PFsK4f4Qy0
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 securemem-0.1.9-6AAYl6PAm7KOCwhTX3JHZ
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-cipher-types-0.0.9-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-cipher-types.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-cipher-types
version: 0.0.9
id: crypto-cipher-types-0.0.9-KCUUibYwQfd3mN2Luf0nrN
key: crypto-cipher-types-0.0.9-KCUUibYwQfd3mN2Luf0nrN
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org
stability: experimental
homepage: http://github.com/vincenthz/hs-crypto-cipher
synopsis: Generic cryptography cipher types
description:
    Generic cryptography cipher types
category: Cryptography
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
exposed-modules:
    Crypto.Cipher.Types Crypto.Cipher.Types.Unsafe
hidden-modules: Crypto.Cipher.Types.GF Crypto.Cipher.Types.Block
                Crypto.Cipher.Types.BlockIO Crypto.Cipher.Types.Stream
                Crypto.Cipher.Types.OfIO Crypto.Cipher.Types.AEAD
                Crypto.Cipher.Types.Base Crypto.Cipher.Types.Utils
abi: 79b4d08504962c78da486b40af9d5a83
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
library-dirs: /usr/lib/ghc-8.0.1/site-local/crypto-cipher-types-0.0.9
data-dir: /usr/share/arm-linux-ghc-8.0.1/crypto-cipher-types-0.0.9
hs-libraries: HScrypto-cipher-types-0.0.9-KCUUibYwQfd3mN2Luf0nrN
depends:
    base-4.9.0.0 byteable-0.1.1-15aIBCArSOBEnGxArzrDTM
    bytestring-0.10.8.1 securemem-0.1.9-EejLErvjcTFDEKlSmM4Et1
haddock-interfaces: /usr/share/doc/haskell-crypto-cipher-types/html/crypto-cipher-types.haddock
haddock-html: /usr/share/doc/haskell-crypto-cipher-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
